Learn R Programming

gaussfacts (version 0.0.4)

gaussfact: Display a Random Fact about Carl Friedrich Gauss

Description

Function to display a randomly chosen fact about Carl Friedrich Gauss

Usage

gaussfact(ind)

# S3 method for gaussfact print(x, width = NULL, ...)

Value

A character vector containing one randomly selected line from the included file. It is of class gaussfact for which an S3 print method will be invoked.

Arguments

ind

Optional index of a quote, or character expression to be matched; if missing a random index value is sampled

x

Default object for print method

width

Optional column width parameter

...

Other optional arguments

Author

Dirk Eddelbuettel

Details

This function displays a randomly chosen line from the included data set of random ‘facts’ about Carl Friedrich Gauss. It is based on corpus curated by Mike Cavers via the https://web.archive.org/web/*/gaussfacts.com site, and kindly made available.

Examples

Run this code
  set.seed(123)
  gaussfact()

Run the code above in your browser using DataLab